<?php

namespace Drupal\http_client_manager_example\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\http_client_manager\Entity\HttpConfigRequest;
use Drupal\http_client_manager\HttpClientInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class ExampleController.
 *
 * @package Drupal\http_client_manager_example\Controller
 */
class ExampleController extends ControllerBase {

  /**
   * JsonPlaceholder Http Client.
   *
   * @var \Drupal\http_client_manager\HttpClientInterface
   */
  protected $httpClient;

  /**
   * {@inheritdoc}
   */
  public function __construct(HttpClientInterface $http_client) {
    $this->httpClient = $http_client;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('example_api.http_client')
    );
  }

  /**
   * Get Client.
   *
   * @return \Drupal\http_client_manager\HttpClientInterface
   *   The Http Client instance.
   */
  public function getClient() {
    return $this->httpClient;
  }

  /**
   * All posts.
   *
   * @return string
   *   The service response.
   */
  public function allPosts() {
    $request = HttpConfigRequest::load('all_posts');

    if ($request) {
      $response = '<pre>' . print_r($request->execute(), true) . '</pre>';
    }
    else {
      $response = $this->t('Unable to load "all_posts" configured request.');
    }

    return [
      '#type' => 'markup',
      '#markup' => $response,
    ];
  }


  /**
   * Find posts.
   *
   * @param int $postId
   *   The post Id.
   *
   * @return string
   *   The service response.
   */
  public function findPosts($postId) {
    $client = $this->getClient();
    $response = $client->findPosts(['postId' => $postId]);

    return [
      '#type' => 'markup',
      '#markup' => '<pre>' . print_r($response, true) . '</pre>',
    ];
  }

}
